@@ -1,4 +1,4 @@
-/* $Id: papi_atkutil.c,v 1.10.2.6 2007/09/23 07:37:49 marcusva Exp $
+/* $Id: papi_atkutil.c,v 1.10.2.7 2008/05/10 08:03:46 marcusva Exp $
  *
  * Copyright (c) 2006, Marcus von Appen
  * All rights reserved.
@@ -373,7 +373,7 @@ static G_CONST_RETURN gchar*
 _class_get_toolkit_version (void)
 {
     debug ("_class_get_toolkit_version\n");
-    return VERSION;
+    return "0.0.5";
 }
 
 /**
