@@ -1,6 +1,6 @@
-# $Id: Renderer.py,v 1.61.2.25 2007/03/23 06:02:21 marcusva Exp $
+# $Id: Renderer.py,v 1.61.2.26 2008/01/12 10:48:06 marcusva Exp $
 #
-# Copyright (c) 2004-2007, Marcus von Appen
+# Copyright (c) 2004-2008, Marcus von Appen
 # All rights reserved.
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are met:
@@ -1062,13 +1062,16 @@ class Renderer (IIndexable):
         else:
             self._loop ()
 
-    def switch_index (self):
-        """R.switch_index () -> None
+    def switch_index (self, reverse=False):
+        """R.switch_index (reverse=False) -> None
 
-        Passes the input focus to the next widget.
+        Passes the input focus to the next or previous widget.
 
-        Passes the input focus to the widget, which is the next
-        focusable after the one with the current focus.
+        Passes the input focus to the widget, which is the next or
+        previous focusable after the one with the current focus.  The
+        default passing is to focus widget with the next higher or equal
+        index set. If the reverse argument is set to True, the previous
+        widget with a lower index is focused.
         """
         indices = None
         if self._activelayer:
@@ -1099,7 +1102,12 @@ class Renderer (IIndexable):
             pos = -1
             
         # Reslice the list and traverse it.
-        widgets = widgets[pos + 1:] + widgets[:pos + 1]
+        if not reverse:
+            widgets = widgets[pos + 1:] + widgets[:pos + 1]
+        else:
+            widgets = widgets[pos:] + widgets[:pos]
+            widgets.reverse ()
+            
         for wid in widgets:
             if (wid != self._indexwidget) and wid.set_focus (True):
                 # Found a widget, which allows to be focused, exit.
@@ -1336,6 +1344,8 @@ class Renderer (IIndexable):
                     if not ismod (event.mod):
                         # Cycle through the widgets of the current layer.
                         self.switch_index ()
+                    elif event.mod & KMOD_SHIFT:
+                        self.switch_index (True)
                     elif event.mod & KMOD_CTRL:
                         # Cycle through the layers.
                         self.switch_layer ()
